#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-refactor-plugin-2.3.0.0-qjoxulwz3Q88D2fu83ovw
key:                  hls-refactor-plugin-2.3.0.0-qjoxulwz3Q88D2fu83ovw
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8eb37b6440dbd8a481efffd725c7f80a
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.3.0.0-qjoxulwz3Q88D2fu83ovw
depends:
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4 base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp extra-1.7.16-J2nH1si97LP2pkcRW1gnIU
    ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-GrsAftRKdtZBX3MfgGGXGX
    ghcide-2.3.0.0-3yCQsM3sLNi5mOrqFn1d0d
    hls-graph-2.3.0.0-EU51DDfcYUwD92bxTtun9V
    hls-plugin-api-2.3.0.0-AhlgRZkAJwO1JNQXcdgGea
    lens-5.3.5-EhGtUvREmRw93iKAzI3qoD
    lsp-2.2.0.0-JJwazOJIAzCJL4eJNeKzRs mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    regex-applicative-0.3.4-Immja1nMjRH45KR9XJ3diN
    regex-tdfa-1.3.2.5-5Xsa8Nkm5ozG5wMRmCPABC
    retrie-1.2.3-20CM8SuzyIO5WLGouxnlfF syb-0.7.4-6oouIIO3k8DpxFQgfxTIJ
    text-2.0.2 text-rope-0.3-EO5ymQqmXhR3J2sULWxVPk time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

